==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fnoargs.h <==
// class soot.coffi.Instruction_noargs

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction

#include "soot/coffi/Instruction.h"

#ifndef _JC_soot_coffi_Instruction__5fnoargs_H_
#define _JC_soot_coffi_Instruction__5fnoargs_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fnoargs$sub_refs	_jc_soot_coffi_Instruction__5fnoargs$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	_jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fnoargs$refs	_jc_soot_coffi_Instruction__5fnoargs$refs;
typedef struct _jc_soot_coffi_Instruction__5fnoargs$nonrefs	_jc_soot_coffi_Instruction__5fnoargs$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fnoargs$object	_jc_soot_coffi_Instruction__5fnoargs$object;

typedef const struct _jc_soot_coffi_Instruction__5fnoargs$vmethods	_jc_soot_coffi_Instruction__5fnoargs$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fnoargs$vtable	_jc_soot_coffi_Instruction__5fnoargs$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fnoargs$vtype	_jc_soot_coffi_Instruction__5fnoargs$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fnoargs$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5fnoargs$object *, jbyte);

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fnoargs$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fnoargs$object *, struct _jc_byte_array *, jint);
extern jint _jc_soot_coffi_Instruction__5fnoargs$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fnoargs$object *, struct _jc_byte_array *, jint);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fnoargs$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fnoargs$method_info$parse$107dd9a35b0eb485;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fnoargs$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fnoargs$object *, struct _jc_byte_array *, jint);
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fnoargs$object *, struct _jc_byte_array *, jint);
};

// Vtable
struct _jc_soot_coffi_Instruction__5fnoargs$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fnoargs$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fnoargs$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fnoargs$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fnoargs$refs {
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fnoargs$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fnoargs$object {
	_jc_soot_coffi_Instruction__5fnoargs$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fnoargs$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fnoargs$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fnoargs$vtype _jc_soot_coffi_Instruction__5fnoargs$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fnoargs, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fnoargs$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fnoargs_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fnoargs.h <==
// class soot.coffi.Instruction_noargs

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction

#include "soot/coffi/Instruction.h"

#ifndef _JC_soot_coffi_Instruction__5fnoargs_H_
#define _JC_soot_coffi_Instruction__5fnoargs_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fnoargs$sub_refs	_jc_soot_coffi_Instruction__5fnoargs$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	_jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fnoargs$refs	_jc_soot_coffi_Instruction__5fnoargs$refs;
typedef struct _jc_soot_coffi_Instruction__5fnoargs$nonrefs	_jc_soot_coffi_Instruction__5fnoargs$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fnoargs$object	_jc_soot_coffi_Instruction__5fnoargs$object;

typedef const struct _jc_soot_coffi_Instruction__5fnoargs$vmethods	_jc_soot_coffi_Instruction__5fnoargs$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fnoargs$vtable	_jc_soot_coffi_Instruction__5fnoargs$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fnoargs$vtype	_jc_soot_coffi_Instruction__5fnoargs$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fnoargs$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5fnoargs$object *, jbyte) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fnoargs$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fnoargs$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fnoargs$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fnoargs$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fnoargs$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fnoargs$method_info$parse$107dd9a35b0eb485;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fnoargs$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fnoargs$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fnoargs$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Instruction__5fnoargs$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fnoargs$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fnoargs$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fnoargs$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fnoargs$refs {
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fnoargs$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fnoargs$object {
	_jc_soot_coffi_Instruction__5fnoargs$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fnoargs$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fnoargs$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fnoargs$vtype _jc_soot_coffi_Instruction__5fnoargs$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fnoargs, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fnoargs$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fnoargs_H_ */
